Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(22)

Unified Diff: chrome/browser/resources/net_internals/requestsview.js

Issue 1593009: Add extra views to the new net internals page. This adds tabs along the top f... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 10 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/net_internals/requestsview.js
===================================================================
--- chrome/browser/resources/net_internals/requestsview.js (revision 43430)
+++ chrome/browser/resources/net_internals/requestsview.js (working copy)
@@ -3,25 +3,55 @@
// found in the LICENSE file.
/**
- * RequestsView is the class which glues together the different components to
- * form the primary UI:
+ * RequestsView displays a filtered list of all the requests, and a details
+ * pane for the selected requests.
*
* - The search filter
* - The requests table
* - The details panel
* - The action bar
*
* @constructor
*/
function RequestsView(tableBodyId, filterInputId, filterCountId,
- deleteSelectedId, selectAllId, detailsView) {
+ deleteSelectedId, selectAllId,
+ tabHandlesContainerId, logTabId, timelineTabId,
+ detailsLogBoxId, detailsTimelineBoxId,
+ topbarId, middleboxId, bottombarId, sizerId) {
+ View.call(this);
+
+ // Initialize the sub-views.
+ var leftPane = new TopMidBottomView(new DivView(topbarId),
+ new DivView(middleboxId),
+ new DivView(bottombarId));
+
+ this.detailsView_ = new DetailsView(tabHandlesContainerId,
+ logTabId,
+ timelineTabId,
+ detailsLogBoxId,
+ detailsTimelineBoxId);
+
+ this.splitterView_ = new ResizableVerticalSplitView(
+ leftPane, this.detailsView_, new DivView(sizerId));
+
this.sourceIdToEntryMap_ = {};
this.currentSelectedSources_ = [];
LogDataProvider.addObserver(this);
this.tableBody_ = document.getElementById(tableBodyId);
- this.detailsView_ = detailsView;
this.filterInput_ = document.getElementById(filterInputId);
this.filterCount_ = document.getElementById(filterCountId);
@@ -43,9 +73,21 @@
this.invalidateDetailsView_();
}
+inherits(RequestsView, View);
+
// How soon after updating the filter list the counter should be updated.
RequestsView.REPAINT_FILTER_COUNTER_TIMEOUT_MS = 0;
+RequestsView.prototype.setGeometry = function(left, top, width, height) {
+ RequestsView.superClass_.setGeometry.call(this, left, top, width, height);
+ this.splitterView_.setGeometry(left, top, width, height);
+};
+
+RequestsView.prototype.show = function(isVisible) {
+ RequestsView.superClass_.show.call(this, isVisible);
+ this.splitterView_.show(isVisible);
+};
+
RequestsView.prototype.onFilterTextChanged_ = function() {
this.setFilter_(this.filterInput_.value);
};
@@ -3,25 +3,55 @@
*
- * - The search filter
- * - The requests table
- * - The details panel
- * - The action bar
+ * +----------------------++----------------+
+ * | filter box || |
+ * +----------------------+| |
+ * | || |
+ * | || |
+ * | || |
+ * | || |
+ * | requests list || details |
+ * | || view |
+ * | || |
+ * | || |
+ * | || |
+ * | || |
+ * +----------------------++ |
+ * | action bar || |
+ * +----------------------++----------------+
*
* @constructor
« no previous file with comments | « chrome/browser/resources/net_internals/main.js ('k') | chrome/browser/resources/net_internals/resizableverticalsplitview.js » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698